BottomNavigationBar class

Constructors

BottomNavigationBar()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

componentOne(BuildContext context, int index, List<Widget> children) Widget
componentTwo(BuildContext context, int index, List<Widget> children) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited