Request class

Constructors

Request()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ssl bool
getter/setter pair
url String
getter/setter pair
widgetLoading Widget?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(String method, String route, {Map<String, String> body = const {}, Map<String, String> headers = const {}, Map<String, String> queryParams = const {}, BuildContext? context}) Future<Response>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

initicalize({required String url, required bool ssl, Widget? widgetLoading}) → void