Requester class
Constructors
-
Requester(String baseUrl, bool ssl, {required String method, required String route, Map<
String, String> headers = const {"Content-Type" : "application/json", "Accept" : "application/json"}, Map<String, String> queryParams = const {}, Map<String, String> body = const {}, bool showLoading = true, BuildContext? context})
Properties
- baseUrl → String
-
final
-
body
↔ Map<
String, String> -
getter/setter pair
- context ↔ BuildContext?
-
getter/setter pair
- data → Object?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
↔ Map<
String, String> -
getter/setter pair
- method ↔ String
-
getter/setter pair
-
queryParams
↔ Map<
String, String> -
getter/setter pair
- route ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLoading ↔ bool
-
getter/setter pair
- ssl → bool
-
final
Methods
-
call(
) → Future< Response> -
delete(
Uri url) → Future< Response> -
get(
Uri url) → Future< Response> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
post(
Uri url) → Future< Response> -
put(
Uri url) → Future< Response> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited